Crate shleazy

Crate shleazy 

Functions

getoutput_shell_or_err
Return Err if non-zero exit code
getstatus
Get exit code, print the output to stdout as it goes
getstatus_shell
Same as getstatus, but wrap in a shell invocation
getstatusoutput
Capture status and output
getstatusoutput_shell
Same as getstatusoutput, but wrap in a shell invocation
run_shell_or_err
Return Err if non-zero exit code