Functions
- getoutput_
shell_ or_ err - Return Err if non-zero exit code
- getstatus
- Get exit code, print the output to stdout as it goes
- getstatus_
shell - Same as getstatus, but wrap in a shell invocation
- getstatusoutput
- Capture status and output
- getstatusoutput_
shell - Same as getstatusoutput, but wrap in a shell invocation
- run_
shell_ or_ err - Return Err if non-zero exit code